@@ -17,13 +17,13 @@ use Data::Table::Text qw(:all);
 use File::Copy;
 use POSIX qw(strftime);                                                         # http://www.cplusplus.com/reference/ctime/strftime/
 
-our $VERSION = '2017.429';
+our $VERSION = '2017.430';
 
 #-------------------------------------------------------------------------------
 # Constants
 #-------------------------------------------------------------------------------
 
-my $home        = currentDirectory;                                             # Home directory
+my $home        = currentDirectory();                                           # Home directory
 my $permissions =                                                               # Default permissions
    [qw(INTERNET ACCESS_WIFI_STATE ACCESS_NETWORK_STATE WRITE_EXTERNAL_STORAGE),
     qw(READ_EXTERNAL_STORAGE RECEIVE_BOOT_COMPLETED)];
@@ -382,7 +382,7 @@ sub make
     $a =~ /Android Debug Bridge/ or confess "adb not found at:\n$adb";
    }
 
-  if (1)                                                                        # Confirm zipalign
+  if (1)                                                                        # Confirm files
    {for(
   [qq(sdk),        $sdk       ],
   [qq(buildTools), $buildTools],
@@ -396,6 +396,8 @@ sub make
      }
    }
 
+  unlink $_ for $api, $apj, $apk;                                               # Remove apks
+
   if (1)                                                                        # Generate R.java
    {makePath($gen);
     xxx("$aapt package -f -m -0 apk -M $manifest -S $res -I $androidJar",
